@@ -1,23 +1,20 @@
 /* Copyright (C) 1999, 2000, Ghostgum Software Pty Ltd.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-// $RCSfile: dwsetup.cpp,v $ $Revision: 1.5.2.2 $
+// $Id: dwsetup.cpp,v 1.5.6.2 2002/04/20 22:11:39 ghostgum Exp $
 //
 //
 // This is the setup program for Win32 GNU Ghostscript
@@ -40,10 +37,10 @@
 // uninstall log files are to be placed.  
 // Subsequent lines contain files to be copied (but not directories).
 // For example, filelist.txt might contain:
-//   GNU Ghostscript 6.52
-//   gs6.52
-//   gs6.52\bin\gsdll32.dll
-//   gs6.52\lib\gs_init.ps
+//   GNU Ghostscript 6.50
+//   gs6.50
+//   gs6.50\bin\gsdll32.dll
+//   gs6.50\lib\gs_init.ps
 // The file fontlist.txt might contain:
 //   GNU Ghostscript Fonts
 //   fonts
