@@ -1,23 +1,20 @@
 /* Copyright (C) 1995, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gdevos2p.c,v $ $Revision: 1.3.2.1 $ */
+/*$Id: gdevos2p.c,v 1.4.2.1 2002/02/22 19:45:56 ray Exp $ */
 /*
  * OS/2 printer device
  *
@@ -150,12 +147,12 @@ os2prn_open(gx_device * dev)
     oprn = opdev;
 
     if (DosGetInfoBlocks(&pptib, &pppib)) {
-	fprintf(stderr, "\nos2prn_open: Couldn't get pid\n");
+	errprintf("\nos2prn_open: Couldn't get pid\n");
 	return gs_error_limitcheck;
     }
     if (pppib->pib_ultype != 3) {
 	/* if caller is not PM app */
-	fprintf(stderr, "os2prn device can only be used from a PM application\n");
+	errprintf("os2prn device can only be used from a PM application\n");
 	return gs_error_limitcheck;
     }
     opdev->hab = WinQueryAnchorBlock(hwndtext);
@@ -191,10 +188,10 @@ os2prn_open(gx_device * dev)
 	pprq = &(opdev->ql.prq[opdev->ql.defqueue]);
     }
     if (pprq == (PRQINFO3 *) NULL) {
-	fprintf(stderr, "Invalid os2prn queue  name -sOS2QUEUE=\042%s\042\n", opdev->queue_name);
-	fprintf(stderr, "Valid device names are:\n");
+	errprintf("Invalid os2prn queue  name -sOS2QUEUE=\042%s\042\n", opdev->queue_name);
+	errprintf("Valid device names are:\n");
 	for (i = 0; i < opdev->ql.nqueues; i++) {
-	    fprintf(stderr, "  -sOS2QUEUE=\042%s\042\n", opdev->ql.prq[i].pszName);
+	    errprintf("  -sOS2QUEUE=\042%s\042\n", opdev->ql.prq[i].pszName);
 	}
 	return gs_error_rangecheck;
     }
@@ -211,7 +208,7 @@ os2prn_open(gx_device * dev)
     if (opdev->hdc == DEV_ERROR) {
 	ERRORID eid = WinGetLastError(opdev->hab);
 
-	fprintf(stderr, "DevOpenDC for printer error 0x%x\n", eid);
+	errprintf("DevOpenDC for printer error 0x%x\n", eid);
 	return gs_error_limitcheck;
     }
     os2prn_free_queue_list(&opdev->ql);
@@ -267,7 +264,7 @@ os2prn_open(gx_device * dev)
     if (opdev->hdcMem == DEV_ERROR) {
 	ERRORID eid = WinGetLastError(opdev->hab);
 
-	fprintf(stderr, "DevOpenDC for memory error 0x%x\n", eid);
+	errprintf("DevOpenDC for memory error 0x%x\n", eid);
 	return gs_error_limitcheck;
     }
     sizlPage.cx = dev->width;
@@ -277,14 +274,14 @@ os2prn_open(gx_device * dev)
     if (opdev->hpsMem == GPI_ERROR) {
 	ERRORID eid = WinGetLastError(opdev->hab);
 
-	fprintf(stderr, "GpiCreatePS for memory error 0x%x\n", eid);
+	errprintf("GpiCreatePS for memory error 0x%x\n", eid);
 	return gs_error_limitcheck;
     }
     if (DevEscape(opdev->hdc, DEVESC_STARTDOC, (LONG) strlen(gs_product),
 		  (char *)gs_product, NULL, NULL) == DEVESC_ERROR) {
 	ERRORID eid = WinGetLastError(opdev->hab);
 
-	fprintf(stderr, "DEVESC_STARTDOC error 0x%x\n", eid);
+	errprintf("DEVESC_STARTDOC error 0x%x\n", eid);
 	return gs_error_limitcheck;
     }
     /* gdev_prn_open opens a temporary file which we don't want */
@@ -685,7 +682,7 @@ os2prn_get_queue_list(OS2QL * ql)
 	}
     } else {
 	/* If we are here we had a bad error code. Print it and some other info. */
-	fprintf(stdout, "SplEnumQueue Error=%ld, Total=%ld, Returned=%ld, Needed=%ld\n",
+	eprintf4("SplEnumQueue Error=%ld, Total=%ld, Returned=%ld, Needed=%ld\n",
 		splerr, cTotal, cReturned, cbNeeded);
     }
     if (splerr)
