@@ -1,23 +1,20 @@
 /* Copyright (C) 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gdevpdfb.c,v $ $Revision: 1.2.2.3 $ */
+/*$Id: gdevpdfb.c,v 1.6.2.1 2002/02/22 19:45:56 ray Exp $ */
 /* Low-level bitmap image handling for PDF-writing driver */
 #include "string_.h"
 #include "gx.h"
@@ -264,8 +261,16 @@ pdf_copy_mono(gx_device_pdf *pdev,
      * that would need to be passed.
      */
     if (pres) {
-	/* Always use CCITTFax 2-D for character bitmaps. */
-	psdf_CFE_binary(&writer.binary, image.Width, image.Height, false);
+	/*
+	 * Always use CCITTFax 2-D for character bitmaps.  It takes less
+	 * space to invert the data with Decode than to set BlackIs1.
+	 */
+	float d0 = image.Decode[0];
+
+	image.Decode[0] = image.Decode[1];
+	image.Decode[1] = d0;
+	psdf_CFE_binary(&writer.binary, image.Width, image.Height, true);
+	invert ^= 0xff;
     } else {
 	/* Use the Distiller compression parameters. */
 	psdf_setup_image_filters((gx_device_psdf *) pdev, &writer.binary,
@@ -527,7 +532,7 @@ gdev_pdf_strip_tile_rectangle(gx_device * dev, const gx_strip_bitmap * tiles,
 	if (code < 0)
 	    goto use_default;
 	s = pdev->strm;
-	pprintd1(s, "/Type/Pattern/PatternType 1/PaintType %d/TilingType 1/Resources<<\n",
+	pprintd1(s, "/PatternType 1/PaintType %d/TilingType 1/Resources<<\n",
 		 (mask ? 2 : 1));
 	if (image_id)
 	    pprintld2(s, "/XObject<</R%ld %ld 0 R>>", image_id, image_id);
