@@ -1,33 +1,31 @@
 /* Copyright (C) 1999, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gdevpdfw.c,v $ $Revision: 1.5.2.3 $ */
+/*$Id: gdevpdfw.c,v 1.12.2.1 2002/02/22 19:45:56 ray Exp $ */
 /* Font writing for pdfwrite driver. */
 #include "memory_.h"
 #include "string_.h"
 #include "gx.h"
+#include "gsalloc.h"		/* for patching font memory */
 #include "gsbittab.h"
 #include "gserrors.h"
-#include "gsmalloc.h"		/* for patching font memory */
 #include "gsmatrix.h"
 #include "gsutil.h"		/* for bytes_compare */
 #include "gxfcid.h"
+#include "gxfcmap.h"
 #include "gxfont.h"
 #include "gxfont0.h"
 #include "gdevpdfx.h"
@@ -52,22 +50,6 @@ pdf_char_proc_id(const pdf_char_proc_t *pcp)
     return pdf_resource_id((const pdf_resource_t *)pcp);
 }
 
-/* Write CIDSystemInfo for a CIDFont or CMap. */
-private void
-pdf_write_CIDSystemInfo(gx_device_pdf *pdev,
-			const gs_cid_system_info_t *pcidsi)
-{
-    stream *s = pdev->strm;
-
-    stream_puts(s, "/CISystemInfo<<\n/Registry");
-    s_write_ps_string(s, pcidsi->Registry.data, pcidsi->Registry.size,
-		      PRINT_HEX_NOT_OK);
-    stream_puts(s, "\n/Ordering");
-    s_write_ps_string(s, pcidsi->Ordering.data, pcidsi->Ordering.size,
-		      PRINT_HEX_NOT_OK);
-    pprintd1(s, "\n/Supplement %d\n>>\n", pcidsi->Supplement);
-}
-
 /* Write the Widths for a font. */
 private int
 pdf_write_Widths(gx_device_pdf *pdev, int first, int last,
@@ -113,7 +95,7 @@ pdf_write_synthesized_type3(gx_device_pdf *pdev, const pdf_font_t *pef)
     memset(widths, 0, sizeof(widths));
     pdf_open_separate(pdev, pdf_font_id(pef));
     s = pdev->strm;
-    pprints1(s, "<</Type/Font/Name/%s/Subtype/Type3", pef->frname);
+    pprints1(s, "<</Type/Font/Name/%s/Subtype/Type3", pef->rname);
     pprintld1(s, "/Encoding %ld 0 R/CharProcs", pdev->embedded_encoding_id);
 
     /* Write the CharProcs. */
@@ -168,16 +150,18 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 	switch (pfd->values.FontType) {
 	case ft_CID_encrypted:
 	case ft_CID_TrueType: {
-	    int i;
+	    pdf_data_writer_t writer;
 
 	    cidset_id = pdf_begin_separate(pdev);
 	    s = pdev->strm;
-	    /****** ADD COMPRESSION + ASCII85 ******/
-	    pprintd1(s, "<</Length %d>>stream\n", (int)pfd->chars_used.size);
-	    for (i = 0; i < pfd->chars_used.size; ++i)
-		stream_putc(s, byte_reverse_bits[pfd->chars_used.data[i]]);
-	    stream_puts(s, "endstream\n");
-	    pdf_end_separate(pdev);
+	    stream_puts(s, "<<");
+	    code = pdf_begin_data(pdev, &writer);
+	    if (code >= 0) {
+		stream_write(writer.binary.strm, pfd->chars_used.data,
+		       pfd->chars_used.size);
+		code = pdf_end_data(&writer);
+	    } else		/* code < 0 */
+		pdf_end_separate(pdev);
 	}
 	default:
 	    break;
@@ -240,7 +224,7 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 		break;
 	    case ft_composite:
 		return_error(gs_error_rangecheck);
-	    default: {
+	    case ft_encrypted: {
 		gs_glyph subset_glyphs[256];
 		uint subset_size = psf_subset_glyphs(subset_glyphs, font,
 						     pfd->chars_used.data);
@@ -259,6 +243,8 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
 		}
 		stream_puts(s, ")\n");
 	    }
+	    default:
+		break;
 	    }
 	}
 	if (pfd->FontFile_id) {
@@ -292,69 +278,274 @@ pdf_write_FontDescriptor(gx_device_pdf *pdev, const pdf_font_descriptor_t *pfd)
     return code;
 }
 
+/* Write CIDSystemInfo for a CIDFont or CMap. */
+private int
+pdf_write_cid_system_info(gx_device_pdf *pdev,
+			  const gs_cid_system_info_t *pcidsi)
+{
+    stream *s = pdev->strm;
+
+    stream_puts(s, "<<\n/Registry");
+    s_write_ps_string(s, pcidsi->Registry.data, pcidsi->Registry.size,
+		      PRINT_HEX_NOT_OK);
+    stream_puts(s, "\n/Ordering");
+    s_write_ps_string(s, pcidsi->Ordering.data, pcidsi->Ordering.size,
+		      PRINT_HEX_NOT_OK);
+    pprintd1(s, "\n/Supplement %d\n>>\n", pcidsi->Supplement);
+    return 0;
+}
+int
+pdf_write_CIDFont_system_info(gx_device_pdf *pdev, const gs_font *pcidfont)
+{
+    const gs_cid_system_info_t *pcidsi;
+
+    switch (pcidfont->FontType) {
+    case ft_CID_encrypted:
+	pcidsi = &((const gs_font_cid0 *)pcidfont)->
+	    cidata.common.CIDSystemInfo;
+	break;
+    case ft_CID_TrueType:
+	pcidsi = &((const gs_font_cid2 *)pcidfont)->
+	    cidata.common.CIDSystemInfo;
+	break;
+    default:
+	return_error(gs_error_rangecheck);
+    }
+    return pdf_write_cid_system_info(pdev, pcidsi);
+}
+int
+pdf_write_CMap_system_info(gx_device_pdf *pdev, const gs_cmap_t *pcmap)
+{
+    return pdf_write_cid_system_info(pdev, pcmap->CIDSystemInfo);
+}
+
+/*
+ * Write the [D]W[2] entries for a CIDFont.  *pfont is known to be a
+ * CIDFont (type 0 or 2).
+ */
+private int
+pdf_write_CIDFont_widths(gx_device_pdf *pdev, const pdf_font_t *ppf)
+{
+    /*
+     * The values of the CIDFont width keys are as follows:
+     *   DW = w (default 0)
+     *   W = [{c [w ...] | cfirst clast w}*]
+     *   DW2 = [vy w1y] (default [880 -1000])
+     *   W2 = [{c [w1y vx vy ...] | cfirst clast w1y vx vy}*]
+     * Currently we only write DW and W.
+     */
+    stream *s = pdev->strm;
+    psf_glyph_enum_t genum;
+    gs_glyph glyph;
+    int dw = 0;
+
+    psf_enumerate_bits_begin(&genum, NULL, ppf->widths_known,
+			     ppf->FontDescriptor->chars_count,
+			     GLYPH_SPACE_INDEX);
+
+    /* Use the most common width as DW. */
+
+    {
+	ushort counts[1001];
+	int dw_count = 0, i;
+
+	memset(counts, 0, sizeof(counts));
+	while (!psf_enumerate_glyphs_next(&genum, &glyph)) {
+	    int width = ppf->Widths[glyph - gs_min_cid_glyph];
+
+	    counts[min(width, countof(counts) - 1)]++;
+	}
+	for (i = 0; i < countof(counts); ++i)
+	    if (counts[i] > dw_count)
+		dw = i, dw_count = counts[i];
+	if (dw != 0)
+	    pprintd1(s, "/DW %d\n", dw);
+    }
+
+    /*
+     * Now write all widths different from DW.  Currently we make no
+     * attempt to optimize this: we write every width individually.
+     */
+
+    psf_enumerate_glyphs_reset(&genum);
+    {
+	int prev = -2;
+
+	while (!psf_enumerate_glyphs_next(&genum, &glyph)) {
+	    int cid = glyph - gs_min_cid_glyph;
+	    int width = ppf->Widths[cid];
+
+	    if (cid == prev + 1)
+		pprintd1(s, "\n%d", width);
+	    else if (width == dw)
+		continue;
+	    else {
+		if (prev >= 0)
+		    stream_puts(s, "]\n");
+		else
+		    stream_puts(s, "/W[");
+		pprintd2(s, "%d[%d", cid, width);
+	    }
+	    prev = cid;
+	}
+	if (prev >= 0)
+	    stream_puts(s, "]]");
+    }    
+
+    return 0;
+}
+
+/*
+ * Write the CIDToGIDMap for a CIDFontType 2 font.  We only need to worry
+ * about mapping CIDs that have actually been used.
+ */
+private int
+pdf_write_CIDToGIDMap(gx_device_pdf *pdev, pdf_font_t *ppf,
+		      long *pcidmap_id)
+{
+    stream *s = pdev->strm;
+    psf_glyph_enum_t genum;
+    gs_glyph glyph;
+
+    psf_enumerate_bits_begin(&genum, NULL, ppf->widths_known,
+			     ppf->FontDescriptor->chars_count,
+			     GLYPH_SPACE_INDEX);
+
+    /* Check for the identity map. */
+    while (!psf_enumerate_glyphs_next(&genum, &glyph)) {
+	int cid = glyph - gs_min_cid_glyph;
+	int gid = ppf->CIDToGIDMap[cid];
+
+	if (gid != cid) {
+	    /*
+	     * The map isn't Identity.  Assign an object ID for writing the
+	     * map later.
+	     */
+	    *pcidmap_id = pdf_obj_ref(pdev);
+	    pprintld1(s, "/CIDToGIDMap %ld 0 R\n", *pcidmap_id);
+	    return 1;
+	}
+    }
+    /* All CIDs and GIDs match. */
+    stream_puts(s, "/CIDToGIDMap/Identity\n");
+    *pcidmap_id = 0;
+    return 0;
+}
+private int
+pdf_write_CIDMap(stream *s, pdf_font_t *ppf)
+{
+    psf_glyph_enum_t genum;
+    int next = 0, count = ppf->FontDescriptor->chars_count;
+    gs_glyph glyph;
+
+    psf_enumerate_bits_begin(&genum, NULL, ppf->widths_known, count,
+			     GLYPH_SPACE_INDEX);
+    while (!psf_enumerate_glyphs_next(&genum, &glyph)) {
+	int cid = glyph - gs_min_cid_glyph;
+	int gid = ppf->CIDToGIDMap[cid];
+
+	for (; next < cid; ++next) {
+	    stream_putc(s, 0); stream_putc(s, 0);
+	}
+	stream_putc(s, (byte)(gid >> 8));
+	stream_putc(s, (byte)gid);
+	next = cid + 1;
+    }
+    for (; next < count; ++next) {
+	stream_putc(s, 0); stream_putc(s, 0);
+    }
+    return 0;
+}
+
 /*
  * Write a font resource, including Widths and/or Encoding if relevant,
  * but not the FontDescriptor or embedded font data.  Note that the
  * font itself may not be available.
+ *
+ * If the font is a subset, we must write the Widths even if it is a
+ * built-in font.
  */
 private int
-pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
-			const gs_const_string *pfname,
-			const gs_const_string *pbfname)
+pdf_write_font_resource(gx_device_pdf *pdev, pdf_font_t *pef,
+			const gs_const_string *pfname)
 {
     stream *s;
     const pdf_font_descriptor_t *pfd = pef->FontDescriptor;
     static const char *const encoding_names[] = {
 	KNOWN_REAL_ENCODING_NAMES
     };
+    /* write_Widths = 0 if not writing, 1 if Widths, -1 if [D]W[2]. */
+    int write_Widths =
+	(pef->write_Widths ||
+	 pdf_has_subset_prefix(pfname->data, pfname->size) ? 1 : 0);
+    long cidmap_id = 0;
+    gs_const_string fname;
+    byte fnchars[MAX_PDF_FONT_NAME];
 
+    fname = *pfname;
     pdf_open_separate(pdev, pdf_font_id(pef));
     s = pdev->strm;
     switch (pef->FontType) {
-    case ft_composite:
-	stream_puts(s, "<</Subtype/Type0");
-	goto bfname;
+    case ft_composite: {
+	byte *chars = pef->fname.chars;
+	uint size = pef->fname.size;
+
+	stream_puts(s, "<</Type/Font/Subtype/Type0/BaseFont");
+	if (pdf_has_subset_prefix(chars, size))
+	    chars += SUBSET_PREFIX_SIZE, size -= SUBSET_PREFIX_SIZE;
+	pdf_put_name(pdev, chars, size);
+	if (pef->sub_font_type == ft_CID_encrypted &&
+	    pef->cmapname[0] == '/'
+	    ) {
+	    stream_putc(s, '-');
+	    pdf_put_name_chars(pdev, (const byte*) (pef->cmapname + 1),
+			       strlen(pef->cmapname + 1));
+	}
+	pprints1(s, "/Encoding %s", pef->cmapname);
+	pprintld1(s, "/DescendantFonts[%ld 0 R]",
+		pdf_resource_id((const pdf_resource_t *)pef->DescendantFont));
+	write_Widths = 0;
+	goto out;
+    }
     case ft_encrypted:
-    case ft_encrypted2: {
-	if (pef->is_MM_instance) {
+    case ft_encrypted2:
 	/*
-	 * If the font is a Multiple Master instance, it should be
-	 * identified as such.  However, Acrobat Reader doesn't seem to
-	 * recognize the MMType1 subtype, but will accept MM Type 1
-	 * instances happily if they are tagged as Type1 (!).
+	 * Multiple Master instances must be identified as such iff they
+	 * are not embedded.
 	 */
-#if 0
+	if (pef->is_MM_instance && !pfd->FontFile_id) {
+	    /* Replace spaces in the name by underscores. */
+	    uint i;
+
 	    stream_puts(s, "<</Subtype/MMType1");
-	    /****** NAME IS WRONG ******/
-#else
-	    stream_puts(s, "<</Subtype/Type1");
-#endif
+	    if (fname.size > sizeof(fnchars))
+		return_error(gs_error_rangecheck);
+	    for (i = 0; i < fname.size; ++i)
+		fnchars[i] = (fname.data[i] == ' ' ? '_' : fname.data[i]);
+	    fname.data = fnchars;
 	} else {
 	    stream_puts(s, "<</Subtype/Type1");
 	}
-    }
     bfname:
 	stream_puts(s, "/BaseFont");
-	pdf_put_name(pdev, pbfname->data, pbfname->size);
+	pdf_put_name(pdev, fname.data, fname.size);
 	break;
     case ft_CID_encrypted:
-	stream_puts(s, "<</Subtype/CIDFontType0");
-	/****** REQUIRES FONT TO EXIST ******/
-	pdf_write_CIDSystemInfo(pdev, &((const gs_font_cid0 *)pfd->base_font)->
-				cidata.common.CIDSystemInfo);
+	pprintld1(s, "<</Subtype/CIDFontType0/CIDSystemInfo %ld 0 R",
+		  pef->CIDSystemInfo_id);
+	write_Widths = -write_Widths;
 	goto bfname;
     case ft_CID_TrueType:
-	stream_puts(s, "<</Subtype/CIDFontType2");
-	/****** REQUIRES FONT TO EXIST ******/
-	pdf_write_CIDSystemInfo(pdev, &((const gs_font_cid2 *)pfd->base_font)->
-				cidata.common.CIDSystemInfo);
+	pprintld1(s, "<</Subtype/CIDFontType2/CIDSystemInfo %ld 0 R",
+		  pef->CIDSystemInfo_id);
+	write_Widths = -write_Widths;
 	goto ttname;
     case ft_TrueType:
 	stream_puts(s, "<</Subtype/TrueType");
     ttname:
 	stream_puts(s, "/BaseFont");
+	pdf_put_name(pdev, fname.data, fname.size);
 	/****** WHAT ABOUT STYLE INFO? ******/
-	pdf_put_name(pdev, pbfname->data, pbfname->size);
 	break;
     default:
 	return_error(gs_error_rangecheck);
@@ -362,9 +553,18 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
     pprintld1(s, "/Type/Font/Name/R%ld", pdf_font_id(pef));
     if (pef->index < 0 || pfd->base_font || pfd->FontFile_id)
 	pprintld1(s, "/FontDescriptor %ld 0 R", pdf_font_descriptor_id(pfd));
-    if (pef->write_Widths)
+    switch (write_Widths) {
+    case 0:
+	break;
+    case 1:
 	pdf_write_Widths(pdev, pef->FirstChar, pef->LastChar, pef->Widths);
-    /****** WRITE CIDFont [D]W[2] ******/
+	break;
+    case -1:
+	pdf_write_CIDFont_widths(pdev, pef);
+	if (pef->FontType == ft_CID_TrueType)
+	    pdf_write_CIDToGIDMap(pdev, pef, &cidmap_id);
+	break;
+    }
     if (pef->Differences) {
 	long diff_id = pdf_obj_ref(pdev);
 	int prev = 256;
@@ -390,6 +590,18 @@ pdf_write_font_resource(gx_device_pdf *pdev, const pdf_font_t *pef,
     } else if (pef->BaseEncoding != ENCODING_INDEX_UNKNOWN) {
 	pprints1(s, "/Encoding/%s", encoding_names[pef->BaseEncoding]);
     }
+    if (cidmap_id) {
+	pdf_data_writer_t writer;
+
+	stream_puts(pdev->strm, ">>\n");
+	pdf_end_separate(pdev);
+	pdf_open_separate(pdev, cidmap_id);
+	stream_puts(pdev->strm, "<<");
+	pdf_begin_data(pdev, &writer);
+	pdf_write_CIDMap(writer.binary.strm, pef);
+	return pdf_end_data(&writer);
+    }
+ out:
     stream_puts(s, ">>\n");
     return pdf_end_separate(pdev);
 }
@@ -413,7 +625,7 @@ pdf_register_font(gx_device_pdf *pdev, gs_font *font, pdf_font_t *ppf)
      * pdev->pdf_memory.
      */
     pdf_font_descriptor_t *pfd = ppf->FontDescriptor;
-    gs_font *base_font = pfd->base_font;
+    gs_font *base_font = (pfd ? pfd->base_font : NULL);
     gs_memory_t *fn_memory = gs_memory_stable(font->memory);
     pdf_font_notify_t *pfn =
 	gs_alloc_struct(fn_memory, pdf_font_notify_t,
@@ -446,7 +658,8 @@ pdf_register_font(gx_device_pdf *pdev, gs_font *font, pdf_font_t *ppf)
 	pfn->pdev = pdev;
 	pfn->pfd = 0;
     }
-    pfd->notified = true;
+    if (pfd)
+	pfd->notified = true;
     pfn->pdfont = ppf;
 #ifdef DEBUG
     if_debug4('_', "[_]register 0x%lx: pdf_font_t 0x%lx => 0x%lx, id %ld\n",
@@ -508,7 +721,6 @@ pdf_font_notify_proc(void *vpfn /*proc_data*/, void *event_data)
 	 * Write the FontDescriptor and, if relevant, the FontFile.
 	 */
 	gs_font *const font = pfd->base_font;
-	gs_memory_t *save_memory = font->memory;
 
 	if_debug4('_',
 		  "[_]  notify 0x%lx: pdf_font_descriptor_t 0x%lx => 0x%lx, id %ld\n",
@@ -518,11 +730,25 @@ pdf_font_notify_proc(void *vpfn /*proc_data*/, void *event_data)
 	 * HACK: temporarily patch the font's memory to one that we know is
 	 * available even during GC or restore.  (Eventually we need to fix
 	 * this by prohibiting implementations of font_info and glyph_info
-	 * from doing any allocations.)
+	 * from doing any allocations.)  However, don't use gs_memory_default
+	 * directly, because some malloc/free implementations (such as the
+	 * default one in some versions of Linux) don't recognize LIFO
+	 * behavior and can wind up allocation huge amounts of address space.
 	 */
-	font->memory = &gs_memory_default;
-	code = pdf_finalize_font_descriptor(pdev, pfd);
-	font->memory = save_memory;
+	{
+	    gs_memory_t *save_memory = font->memory;
+	    gs_ref_memory_t *fmem =
+		ialloc_alloc_state((gs_raw_memory_t *)&gs_memory_default,
+				   5000);
+
+	    if (fmem == 0)
+		return_error(gs_error_VMerror);
+	    font->memory = (gs_memory_t *)fmem;
+	    code = pdf_finalize_font_descriptor(pdev, pfd);
+	    gs_memory_free_all((gs_memory_t *)fmem, FREE_ALL_EVERYTHING,
+			       "pdf_font_notify_proc");
+	    font->memory = save_memory;
+	}
     }
     gs_free_object(pfn->memory, vpfn, "pdf_font_notify_proc");
     return code;
@@ -542,6 +768,8 @@ pdf_write_font_resources(gx_device_pdf *pdev)
 {
     int j;
 
+    /* Write the fonts and descriptors. */
+
     for (j = 0; j < NUM_RESOURCE_CHAINS; ++j) {
 	pdf_font_t *ppf;
 	pdf_font_descriptor_t *pfd;
@@ -551,27 +779,40 @@ pdf_write_font_resources(gx_device_pdf *pdev)
 	     ) {
 	    if (PDF_FONT_IS_SYNTHESIZED(ppf))
 		pdf_write_synthesized_type3(pdev, ppf);
-	    else if (!ppf->skip) {
+	    else {
 		gs_const_string font_name;
 
 		pfd = ppf->FontDescriptor;
-		font_name.data = pfd->FontName.chars;
-		font_name.size = pfd->FontName.size;
-		/*
-		 * If the font is based on one of the built-in fonts,
-		 * we already ensured it uses the built-in name.
-		 * If it is a subset, we must write the Widths even if
-		 * it is a built-in font.
-		 */
-		if (pdf_has_subset_prefix(font_name.data, font_name.size))
-		    ppf->write_Widths = true;
-		pdf_write_font_resource(pdev, ppf, &font_name, &font_name);
+		if (pfd) {
+		    font_name.data = pfd->FontName.chars;
+		    font_name.size = pfd->FontName.size;
+		} else {	/* must be composite */
+		    font_name.data = 0;
+		    font_name.size = 0;
+		}
+		pdf_write_font_resource(pdev, ppf, &font_name);
 		if (ppf->font)
 		    gs_notify_unregister_calling(&ppf->font->notify_list,
 						 pdf_font_notify_proc, NULL,
 						 pdf_font_unreg_proc);
 	    }
 	}
+
+	for (ppf = (pdf_font_t *)pdev->resources[resourceCIDFont].chains[j];
+	     ppf != 0; ppf = ppf->next
+	     ) {
+	    gs_const_string font_name;
+
+	    pfd = ppf->FontDescriptor;
+	    font_name.data = pfd->FontName.chars;
+	    font_name.size = pfd->FontName.size;
+	    pdf_write_font_resource(pdev, ppf, &font_name);
+	    if (ppf->font)
+		gs_notify_unregister_calling(&ppf->font->notify_list,
+					     pdf_font_notify_proc, NULL,
+					     pdf_font_unreg_proc);
+	}
+
 	for (pfd = (pdf_font_descriptor_t *)pdev->resources[resourceFontDescriptor].chains[j];
 	     pfd != 0; pfd = pfd->next
 	     ) {
@@ -583,6 +824,33 @@ pdf_write_font_resources(gx_device_pdf *pdev)
 						 pdf_font_unreg_proc);
 	    }
 	}
+
     }
+
+    /* If required, write the Encoding for Type 3 bitmap fonts. */
+
+    if (pdev->embedded_encoding_id) {
+	stream *s;
+	int i;
+
+	pdf_open_separate(pdev, pdev->embedded_encoding_id);
+	s = pdev->strm;
+	/*
+	 * Even though the PDF reference documentation says that a
+	 * BaseEncoding key is required unless the encoding is
+	 * "based on the base font's encoding" (and there is no base
+	 * font in this case), Acrobat 2.1 gives an error if the
+	 * BaseEncoding key is present.
+	 */
+	stream_puts(s, "<</Type/Encoding/Differences[0");
+	for (i = 0; i <= pdev->max_embedded_code; ++i) {
+	    if (!(i & 15))
+		stream_puts(s, "\n");
+	    pprintd1(s, "/a%d", i);
+	}
+	stream_puts(s, "\n] >>\n");
+	pdf_end_separate(pdev);
+    }
+
     return 0;
 }
