@@ -1,23 +1,20 @@
 /* Copyright (C) 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gdevpsfx.c,v $ $Revision: 1.5.2.2 $ */
+/*$Id: gdevpsfx.c,v 1.9.2.1 2002/02/22 19:45:56 ray Exp $ */
 /* Convert Type 1 Charstrings to Type 2 */
 #include "math_.h"
 #include "memory_.h"
@@ -48,7 +45,7 @@ private void
 skip_iv(gs_type1_state *pcis)
 {
     int skip = pcis->pfont->data.lenIV;
-    ip_state *ipsp = &pcis->ipstack[pcis->ips_count - 1];
+    ip_state_t *ipsp = &pcis->ipstack[pcis->ips_count - 1];
     const byte *cip = ipsp->char_string.data;
     crypt_state state = crypt_charstring_seed;
 
@@ -74,6 +71,7 @@ type1_next_init(gs_type1_state *pcis, const gs_const_string *pstr,
     pcis->flex_count = flex_max;
     pcis->dotsection_flag = dotsection_out;
     pcis->ipstack[0].char_string = *pstr;
+    pcis->ipstack[0].free_char_string = 0;
     skip_iv(pcis);
 }
 
@@ -89,14 +87,16 @@ private int
 type1_callsubr(gs_type1_state *pcis, int index)
 {
     gs_font_type1 *pfont = pcis->pfont;
+    ip_state_t *ipsp1 = &pcis->ipstack[pcis->ips_count];
     int code = pfont->data.procs.subr_data(pfont, index, false,
-			&pcis->ipstack[pcis->ips_count].char_string);
+					   &ipsp1->char_string);
 
     if (code < 0)
 	return_error(code);
+    ipsp1->free_char_string = code;
     pcis->ips_count++;
     skip_iv(pcis);
-    return 0;
+    return code;
 }
 
 /* Add 1 or 3 stem hints. */
@@ -148,7 +148,7 @@ type1_stem3(gs_type1_state *pcis, stem_hint_table *psht, const fixed *pv3,
 private int
 type1_next(gs_type1_state *pcis)
 {
-    ip_state *ipsp = &pcis->ipstack[pcis->ips_count - 1];
+    ip_state_t *ipsp = &pcis->ipstack[pcis->ips_count - 1];
     const byte *cip;
     crypt_state state;
 #define CLEAR (csp = pcis->ostack - 1)
@@ -210,6 +210,10 @@ type1_next(gs_type1_state *pcis)
 	    ++ipsp;
 	    goto load;
 	case c_return:
+	    if (ipsp->free_char_string > 0)
+		gs_free_const_string(pcis->pfont->memory,
+				     ipsp->char_string.data,
+				     ipsp->char_string.size, "type1_next");
 	    pcis->ips_count--;
 	    --ipsp;
 	    goto load;
@@ -795,7 +799,7 @@ psf_convert_type1_to_type2(stream *s, const gs_const_string *pstr,
 	    case cx_vhcurveto:
 		if (depth & 1)
 		    goto copy;
-		if (depth & 4)
+		if (!(depth & 4))
 		    goto vrc;
 	    hrc:  /* (hvcurveto vhcurveto)+ hrcurveto => hvcurveto */
 		/* vhcurveto (hvcurveto vhcurveto)* hrcurveto => vhcurveto */
