@@ -1,23 +1,20 @@
 /* Copyright (C) 1992, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gp_ntfs.c,v $ $Revision: 1.4.2.4 $ */
+/*$Id: gp_ntfs.c,v 1.5.2.3 2002/02/22 19:45:57 ray Exp $ */
 /* file system stuff for MS-Windows WIN32 and MS-Windows NT */
 /* hacked from gp_dosfs.c by Russell Lang */
 
@@ -208,16 +205,16 @@ gp_enumerate_files_next(file_enum * pfen, char *ptr, uint maxlen)
 {
     int code = 0;
     uint len;
-    for(;;)
-      { if (pfen->first_time)
+    for(;;) 
+      { if (pfen->first_time) 
           { pfen->find_handle = FindFirstFile(pfen->pattern, &(pfen->find_data));
 	    if (pfen->find_handle == INVALID_HANDLE_VALUE)
 	      { code = -1;
                 break;
               }
 	    pfen->first_time = 0;
-          }
-        else
+          } 
+        else 
           { if (!FindNextFile(pfen->find_handle, &(pfen->find_data)))
 	      { code = -1;
                 break;
@@ -226,8 +223,8 @@ gp_enumerate_files_next(file_enum * pfen, char *ptr, uint maxlen)
         if ( strcmp(".",  pfen->find_data.cFileName)
           && strcmp("..", pfen->find_data.cFileName))
             break;
-      }
-
+      } 
+   
     if (code != 0) {		/* All done, clean up. */
 	gp_enumerate_files_close(pfen);
 	return ~(uint) 0;
