@@ -1,29 +1,27 @@
 /* Copyright (C) 1997, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: gsfcmap.c,v $ $Revision: 1.8.2.5 $ */
+/*$Id: gsfcmap.c,v 1.14.2.2 2002/04/02 13:27:37 mpsuzuki Exp $ */
 /* CMap character decoding */
 #include "memory_.h"
 #include "errors.h"
 #include "gx.h"
 #include "gserrors.h"
 #include "gsstruct.h"
+#include "gsutil.h"		/* for gs_next_ids */
 #include "gxfcmap.h"
 
 /* GC descriptors */
@@ -70,9 +68,84 @@ void
 gs_cmap_init(gs_cmap_t *pcmap)
 {
     memset(pcmap, 0, sizeof(*pcmap));
+    pcmap->id = gs_next_ids(1);
     uid_set_invalid(&pcmap->uid);
 }
 
+/*
+ * Create an Identity CMap.
+ */
+int
+gs_cmap_create_identity(gs_cmap_t **ppcmap, int num_bytes, int wmode,
+			gs_memory_t *mem)
+{
+    gs_cmap_t *pcmap =
+	gs_alloc_struct(mem, gs_cmap_t, &st_cmap,
+			"gs_cmap_create_identity(CMap)");
+    gx_code_space_range_t *range = (gx_code_space_range_t *)
+	gs_alloc_bytes(mem, sizeof(gx_code_space_range_t),
+		       "gs_cmap_create_identity(code space range)");
+    gx_code_lookup_range_t *lookup =
+	gs_alloc_struct_array(mem, 1, gx_code_lookup_range_t,
+			      &st_code_lookup_range,
+			      "gs_cmap_create_identity(lookup range)");
+    /* We allocate CIDSystemInfo dynamically only for the sake of the GC. */
+    gs_cid_system_info_t *pcidsi =
+	gs_alloc_struct(mem, gs_cid_system_info_t, &st_cid_system_info,
+			"gs_cmap_create_identity(CIDSystemInfo)");
+    static const byte key_data[8] = {
+	0, 0, 0, 0, 0xff, 0xff, 0xff, 0xff
+    };
+    static const gs_cid_system_info_t identity_cidsi = {
+	{ (const byte *)"Adobe", 5 },
+	{ (const byte *)"Identity", 8 },
+	0
+    };
+
+    if (pcmap == 0 || range == 0 || lookup == 0 || pcidsi == 0)
+	return_error(gs_error_VMerror);
+    if (num_bytes != 2)		/* for now */
+	return_error(gs_error_rangecheck);
+    gs_cmap_init(pcmap);
+    pcmap->CMapType = 1;
+    pcmap->CMapName.data = (const byte *)
+	(wmode ? "Identity-V" : "Identity-H");
+    pcmap->CMapName.size = 10;
+    *pcidsi = identity_cidsi;
+    pcmap->CIDSystemInfo = pcidsi;
+    pcmap->num_fonts = 1;
+    pcmap->CMapVersion = 1.0;
+    /* no uid, UIDOffset */
+    pcmap->WMode = wmode;
+    memset(range->first, 0, num_bytes);
+    memset(range->last, 0xff, num_bytes);
+    range->size = num_bytes;
+    pcmap->code_space.ranges = range;
+    pcmap->code_space.num_ranges = 1;
+    memset(lookup, 0, sizeof(*lookup));
+    lookup->cmap = pcmap;
+    lookup->key_size = num_bytes;
+    lookup->num_keys = 1;
+    lookup->key_is_range = true;
+    /*
+     * It's OK to break const here, because the strings are never
+     * freed, and the GC can handle strings outside the heap.
+     */
+    lookup->keys.data = (byte*) (key_data + 4 - num_bytes);
+    lookup->keys.size = num_bytes * 2;
+    lookup->value_type = CODE_VALUE_CID;
+    lookup->value_size = num_bytes;
+    /* ditto */
+    lookup->values.data = (byte*) key_data;
+    lookup->values.size = num_bytes;
+    pcmap->def.lookup = lookup;
+    pcmap->def.num_lookup = 1;
+    /* no notdef */
+    /* no mark_glyph, mark_glyph_data, glyph_name, glyph_name_data */
+    *ppcmap = pcmap;
+    return 0;
+}
+
 /*
  * multi-dimensional range comparator
  */
@@ -121,7 +194,7 @@ gs_multidim_CID_offset(const byte *key_str,
 			int key_size)
 {
 
-    int i;      /* index for current dimension */
+    int i;	/* index for current dimension */
     int CID_offset = 0;
 
     if (gs_debug_c('J')) {
@@ -132,7 +205,7 @@ gs_multidim_CID_offset(const byte *key_str,
     for (i = 0; i < key_size; i++)
         CID_offset = CID_offset * (key_hi[i] - key_lo[i] + 1) +
             key_str[i] - key_lo[i];
-
+ 
     if_debug1('J', "[J]gmCo()         CID_offset = %d\n", CID_offset);
     return CID_offset;
 }
@@ -265,7 +338,7 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
         dlprintf3(") @ 0x%lx ssize=%d, %d ranges to check\n",
                        str, ssize, pcmap->num_lookup);
     }
-
+ 
     for (i = pcmap->num_lookup - 1; i >= 0; --i) {
 	/* main loop - scan the map passed via pcmap */
 	/* reverse scan order due to 'usecmap' */
@@ -284,17 +357,16 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
 
         if (0 < pre_size) {
             const byte * prefix = pclr->key_prefix;
-
             /* check partial match in prefix */
             for (j = 0; j < pre_size; j++)
                if (prefix[j] != str[j])
                    break;
 
-            if (0 == j)                 /* no match, skip to next i */
+            if (0 == j)			/* no match, skip to next i */
                 continue;
-            else if (j < pre_size) {    /* not exact, partial match */
-                if (gs_debug_c('j')) {
-                    dlprintf("[j]CMDNmr() partial match with prefix:");
+            else if (j < pre_size) {	/* not exact, partial match */
+                if (gs_debug_c('J')) {
+                    dlprintf("[J]CMDNmr() partial match with prefix:");
                     print_msg_str_in_range(str, prefix,
                                                 prefix, pre_size);
                 }
@@ -308,8 +380,8 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
                 continue ; /* no need to check key, skip to next i */
             }
 
-            if (gs_debug_c('j')) {
-                dlprintf("[j]CMDNmr()   full match with prefix:");
+            if (gs_debug_c('J')) {
+                dlprintf("[J]CMDNmr()   full match with prefix:");
                 print_msg_str_in_range(str, prefix, prefix, pre_size);
             }
 
@@ -322,29 +394,29 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
             int k, l, m;
             const byte *pvalue = NULL;
 
-            /* when range is "range", 2 keys for lo-end and hi-end
-             * are stacked. So twice the step. current "key" points
+	    /* when range is "range", 2 keys for lo-end and hi-end
+	     * are stacked. So twice the step. current "key" points
 	     * lo-end of current range, and the pointer for hi-end
 	     * is calculated by (key + step - key_size).
 	     */
-            if (pclr->key_is_range) {
-                step <<=1;      /* step = step * 2; */
-	    }
+
+            if (pclr->key_is_range)
+		step <<=1; 	/* step = step * 2; */
 
             for (k = 0; k < pclr->num_keys; ++k, key += step) {
 
-                if_debug0('j', "[j]CMDNmr()     check key:");
-                if (gs_debug_c('j'))
-                    print_msg_str_in_range(str + pre_size,
-                                         key, key + step - key_size, key_size);
+		if_debug0('j', "[j]CMDNmr()     check key:");
+		if (gs_debug_c('j'))
+		    print_msg_str_in_range(str + pre_size,
+		        key, key + step - key_size, key_size) ;
 
-                for (l = 0; l < key_size; l++) {
-                    byte c = str[l + pre_size];
-                    if (c < key[l] || c > key[step - key_size + l])
-                        break;
-                }
+		for (l = 0; l < key_size; l++) {
+		    byte c = str[l + pre_size];
+		    if (c < key[l] || c > key[step - key_size + l])
+			break;
+		}
 
-                if (pm_maxlen < pre_size + l) {
+		if (pm_maxlen < pre_size + l) {
                     pm_maxlen = chr_size;
                     pm_chr = bytes2int(str, chr_size);
                     pm_index = (*pindex) + chr_size;
@@ -352,7 +424,7 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
                 }
                 if (l == key_size)
                         break;
-            }
+	    }
 
             /* all keys are tried, but found no match. */
             /* go to next prefix. */
@@ -366,11 +438,11 @@ code_map_decode_next_multidim_regime(const gx_code_map_t * pcmap,
             pvalue = pclr->values.data + k * pclr->value_size;
 
             if (gs_debug_c('J')) {
-                dlprintf1("[J]CMDNmr()     full matched pvalue = %d (= 0x", bytes2int(pvalue, pclr->value_size));
+                dlprintf("[J]CMDNmr()     full matched pvalue=(");
                 debug_print_string_hex(pvalue, pclr->value_size);
                 dlprintf(")\n");
             }
- 
+
             switch (pclr->value_type) {
             case CODE_VALUE_CID:
                 *pglyph = gs_min_cid_glyph +
@@ -500,12 +572,14 @@ gs_cmap_decode_next(const gs_cmap_t * pcmap, const gs_const_string * pstr,
             /* Undecodable string is shorter than the shortest character,
              * there's no way except to return error.
              */
+	    *pglyph = gs_no_glyph;
+	    return -1;
             if (gs_debug_c('J')) {
                 dlprintf2("[J]GCDN() left data in buffer (%d) is shorter than shortest defined character (%d)\n",
-                    ssize, chr_size_shortest);
+                  ssize, chr_size_shortest);
             }
-	    *pglyph = gs_no_glyph;
-	    return_error(e_rangecheck);
+            *pglyph = gs_no_glyph;
+            return_error(e_rangecheck);
 	}
     }
 }
