@@ -1,23 +1,20 @@
 /* Copyright (C) 1992, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: zcie.c,v $ $Revision: 1.4.2.1 $ */
+/*$Id: zcie.c,v 1.5.2.1 2002/02/22 19:46:00 ray Exp $ */
 /* CIE color operators */
 #include "math_.h"
 #include "memory_.h"
@@ -270,8 +267,8 @@ cie_abc_param(const ref * pdref, gs_cie_abc * pcie, ref_cie_procs * pcprocs)
 }
 
 /* Finish setting a CIE space (successful or not). */
-private int
-set_cie_finish(i_ctx_t *i_ctx_p, gs_color_space * pcs,
+int
+cie_set_finish(i_ctx_t *i_ctx_p, gs_color_space * pcs,
 	       const ref_cie_procs * pcprocs, int edepth, int code)
 {
     if (code >= 0)
@@ -279,7 +276,7 @@ set_cie_finish(i_ctx_t *i_ctx_p, gs_color_space * pcs,
     /* Delete the extra reference to the parameter tables. */
     gs_cspace_release(pcs);
     /* Free the top-level object, which was copied by gs_setcolorspace. */
-    gs_free_object(gs_state_memory(igs), pcs, "set_cie_finish");
+    gs_free_object(gs_state_memory(igs), pcs, "cie_set_finish");
     if (code < 0) {
 	ref_stack_pop_to(&e_stack, edepth);
 	return code;
@@ -338,7 +335,7 @@ zsetciedefgspace(i_ctx_t *i_ctx_p)
 	(code = cache_abc_common(i_ctx_p, (gs_cie_abc *)pcie, &procs, pcie, imem)) < 0
 	)
 	DO_NOTHING;
-    return set_cie_finish(i_ctx_p, pcs, &procs, edepth, code);
+    return cie_set_finish(i_ctx_p, pcs, &procs, edepth, code);
 }
 private int
 cie_defg_finish(i_ctx_t *i_ctx_p)
@@ -396,7 +393,7 @@ zsetciedefspace(i_ctx_t *i_ctx_p)
 	(code = cache_abc_common(i_ctx_p, (gs_cie_abc *)pcie, &procs, pcie, imem)) < 0
 	)
 	DO_NOTHING;
-    return set_cie_finish(i_ctx_p, pcs, &procs, edepth, code);
+    return cie_set_finish(i_ctx_p, pcs, &procs, edepth, code);
 }
 private int
 cie_def_finish(i_ctx_t *i_ctx_p)
@@ -439,7 +436,7 @@ zsetcieabcspace(i_ctx_t *i_ctx_p)
 	(code = cache_abc_common(i_ctx_p, pcie, &procs, pcie, imem)) < 0
 	)
 	DO_NOTHING;
-    return set_cie_finish(i_ctx_p, pcs, &procs, edepth, code);
+    return cie_set_finish(i_ctx_p, pcs, &procs, edepth, code);
 }
 private int
 cie_abc_finish(i_ctx_t *i_ctx_p)
@@ -487,7 +484,7 @@ zsetcieaspace(i_ctx_t *i_ctx_p)
 	)
 	DO_NOTHING;
     pcie->DecodeA = DecodeA_default;
-    return set_cie_finish(i_ctx_p, pcs, &procs, edepth, code);
+    return cie_set_finish(i_ctx_p, pcs, &procs, edepth, code);
 }
 private int
 cie_a_finish(i_ctx_t *i_ctx_p)
