@@ -1,23 +1,21 @@
+
 /* Copyright (C) 1996, 2000 Aladdin Enterprises.  All rights reserved.
   
-  This file is part of GNU Ghostscript.
+  This software is provided AS-IS with no warranty, either express or
+  implied.
   
-  GNU Ghostscript is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
-  to anyone for the consequences of using it or for whether it serves any
-  particular purpose or works at all, unless he says so in writing.  Refer
-  to the GNU General Public License for full details.
+  This software is distributed under license and may not be copied,
+  modified or distributed except as expressly authorized under the terms
+  of the license contained in the file LICENSE in this distribution.
   
-  Everyone is granted permission to copy, modify and redistribute GNU
-  Ghostscript, but only under the conditions described in the GNU General
-  Public License.  A copy of this license is supposed to have been given
-  to you along with GNU Ghostscript so you can know your rights and
-  responsibilities.  It should be in a file named COPYING.  Among other
-  things, the copyright notice and this notice must be preserved on all
-  copies.
+  For more information about licensing, please refer to
+  http://www.ghostscript.com/licensing/. For information on
+  commercial licensing, go to http://www.artifex.com/licensing/ or
+  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
 */
 
-/*$RCSfile: zusparam.c,v $ $Revision: 1.3.2.2 $ */
+/*$Id: zusparam.c,v 1.3.6.2 2002/02/22 19:46:01 ray Exp $ */
 /* User and system parameter operators */
 #include "memory_.h"
 #include "string_.h"
@@ -48,9 +46,11 @@ extern gs_font_dir *ifont_dir;	/* in zfont.c */
 /* Eventually this will be made public. */
 #define param_def_common\
     const char *pname
+
 typedef struct param_def_s {
     param_def_common;
 } param_def_t;
+
 typedef struct long_param_def_s {
     param_def_common;
     long min_value, max_value;
@@ -63,11 +63,13 @@ typedef struct long_param_def_s {
 #else
 #  define MAX_UINT_PARAM max_long
 #endif
+
 typedef struct bool_param_def_s {
     param_def_common;
     bool (*current)(P1(i_ctx_t *));
     int (*set)(P2(i_ctx_t *, bool));
 } bool_param_def_t;
+
 typedef struct string_param_def_s {
     param_def_common;
     void (*current)(P2(i_ctx_t *, gs_param_string *));
@@ -449,7 +451,6 @@ set_AccurateScreens(i_ctx_t *i_ctx_p, bool val)
     gs_setaccuratescreens(val);
     return 0;
 }
-
 private bool
 current_LockFilePermissions(i_ctx_t *i_ctx_p)
 {
@@ -464,7 +465,6 @@ set_LockFilePermissions(i_ctx_t *i_ctx_p, bool val)
     i_ctx_p->LockFilePermissions = val;
     return 0;
 }
-
 private const bool_param_def_t user_bool_params[] =
 {
     {"AccurateScreens", current_AccurateScreens, set_AccurateScreens},
@@ -476,7 +476,7 @@ private const param_set user_param_set =
 {
     user_long_params, countof(user_long_params),
     user_bool_params, countof(user_bool_params),
-    0, 0
+    0, 0 
 };
 
 /* <dict> .setuserparams - */
